.. _install:

Installation of SFrout
======================

Each journey start with first step. Let's install **SFrout** 

In current version **SFrout** requires Python 3.11 and works best on Windows 10.


Environment (optional)
---------------------- 

**SFrout** relies on multiple libraries. To avoid making mess in local PIP 
calaogue, I encourage you to install **SFrout** in virtual environment. It doesn't 
effect on the way how the program works, it's prevent making mess in yout PIP.

Navigate to some folder::

    $ cd c:/path/to/venv

Create Python virtual environment::

    - for Windows:

        $ c:\path\to\venv\Scripts\activate.bat

    - for Unix:

        $ source /path/to/venv/bin/activate


Installation
------------

To install SFrout, run short command in any terminal::

    $ python -m pip install sfrout

or 

    $ pip install sfrout


Upgrade
-------

To upgrade SFrout, similiar to installation, add one parameter::

    $ python -m pip install sfrout --upgrade

or:: 

    $ pip install sfrout --upgrade
